package com.akamai.osmf.samples.presenter
{
	import com.akamai.hd.HDMBRObject;
	import com.akamai.osmf.samples.view.BaseVideoView;
	import com.akamai.osmf.utils.AkamaiMediaUtils;
	import com.akamai.osmf.utils.AkamaiStrings;
	
	import org.osmf.media.MediaFactory;
	import org.osmf.media.MediaPlayer;
	import org.osmf.media.URLResource;
	import org.osmf.metadata.Metadata;
	import org.osmf.net.StreamType;
	import org.osmf.net.StreamingURLResource;
	
	// Enable this for proper playback of VOD content only, not for use with LIVE streams. (example VOD can be found commented out on line 40)
	//import com.akamai.hd.HDVODFormatter;
	
	public class HDMBRObjectControlBarPresenter extends BaseControlBarPresenter
	{
		private var hdMBRObject:HDMBRObject;
		private var hdMBRObjects:Array;

		private var resource:StreamingURLResource;
		
		public function HDMBRObjectControlBarPresenter(view:BaseVideoView, mediaPlayer:MediaPlayer, mediaFactory:MediaFactory, mediaResource:String)
		{	
			hdMBRObject = new HDMBRObject();
			hdMBRObjects = new Array();

			
			hdMBRObject.httpBase = "http://efvod-hdnetwork.akamai.com.edgesuite.net/";
			// These bitrates are in kbps
			hdMBRObject.addStream("ElephantsDream2_h264_300@14411", 300);			
			hdMBRObject.addStream("ElephantsDream2_h264_700@14411", 700);
			hdMBRObject.addStream("ElephantsDream2_h264_1500@14411", 1500);
			hdMBRObject.addStream("ElephantsDream2_h264_2500@14411", 2500);
			hdMBRObject.addStream("ElephantsDream2_h264_3500@14411", 3500);

/*
			// VOD EXAMPLE		
			
			hdMBRObject.httpBase = "http://tceast-f.hdflash.edgesuite.net/";
           /// These bitrates are in kbps            
			hdMBRObject.addStream("marketing/adrenaline/AdrenalineRush_512x288_450_b.mp4", 450);
			hdMBRObject.addStream("marketing/adrenaline/AdrenalineRush_640x360_700_b.mp4", 700);
			hdMBRObject.addStream("marketing/adrenaline/AdrenalineRush_1024x576_1400_m.mp4", 1400);
			hdMBRObject.addStream("marketing/adrenaline/AdrenalineRush_1280x720_2500_m.mp4", 2500);
			hdMBRObject.addStream("marketing/adrenaline/AdrenalineRush_1280x720_3500_m.mp4", 3500);
			// Enable this for proper playback of VOD content only, not for use with LIVE streams. 
			hdMBRObject = HDVODFormatter.format(hdMBRObject);
			
*/
			
			hdMBRObjects.push(hdMBRObject);
			
			resource = new StreamingURLResource(mediaResource,StreamType.LIVE_OR_RECORDED);
			
			AkamaiMediaUtils.addAkamaiMediaTypeToResource(resource,AkamaiStrings.AKAMAI_MEDIA_TYPE_HDN_MBR, hdMBRObjects);
			
			addMetadata(resource);
			
			super(view, mediaPlayer, mediaFactory, mediaResource);
		}
		
		override protected function setupMediaPlayer():void
		{
			mediaPlayer.autoPlay = false;
			setupMediaPlayerListeners();
			mediaPlayer.media = mediaFactory.createMediaElement(resource);
		}
		
		private function addMetadata(resource:URLResource):void
		{
			var metadata:Metadata = resource.getMetadataValue(AkamaiStrings.AKAMAI_ADVANCED_STREAMING_PLUGIN_METADATA_NAMESPACE) as Metadata;

			if (metadata == null)
			{
				metadata = new Metadata();		
			}
			
			// Use one or the other of these metadata keys. If both are supplied, the plugin
			// will look at the starting bitrate to determine the corresponding index and 
			// use the lesser of the two indices.			
			//metadata.addValue(AkamaiStrings.AKAMAI_METDATA_KEY_MBR_STARTING_INDEX, 2);
			//metadata.addValue(AkamaiStrings.AKAMAI_METADATA_KEY_MBR_STARTING_BITRATE, 1500);
						
			resource.addMetadataValue(AkamaiStrings.AKAMAI_ADVANCED_STREAMING_PLUGIN_METADATA_NAMESPACE, metadata);			
		}
		
	}
}
