package
{
	import com.akamai.net.f4f.hds.AkamaiLiveArchiveTransitionHandler;
	import com.akamai.net.f4f.hds.events.AkamaiLiveArchiveTransitionEvent;
	import com.akamai.osmf.AkamaiAdvancedStreamingPluginInfo;
	import com.akamai.osmf.samples.BaseSample;
	import com.akamai.osmf.samples.presenter.BaseControlBarPresenter;
	import com.akamai.osmf.samples.presenter.SampleControlBarPresenter;
	import com.akamai.osmf.samples.view.BaseVideoView;
	import com.akamai.osmf.samples.view.SampleVideoView;
	import com.akamai.osmf.utils.AkamaiStrings;
	
	import flash.events.Event;
	
	import org.osmf.events.MediaElementEvent;
	import org.osmf.events.TimeEvent;
	import org.osmf.media.MediaElement;
	import org.osmf.media.MediaResourceBase;
	import org.osmf.metadata.Metadata;
	import org.osmf.net.StreamType;
	import org.osmf.net.StreamingURLResource;
	import org.osmf.traits.MediaTraitType;
	import org.osmf.traits.PlayTrait;
	
	[SWF(width="640", height="390", frameRate="20", backgroundColor="#000000")]
	
	/**
	 //****************************************************************************************
	 // This sample demonstrates an AASP based player that is able to connect to a live archive
	 // stream if EOS is encountered when the player is playing behind live.
	 //
	 // The onComplete() event handler has the reconnection logic.
	 //
	 // When the live archive manifest is requested by HDCore, it fires a custom AkamaiLiveArchiveTransitionEvent.
	 // The event time could either be requested or complete.
	 //
	 // When the event type is complete, the mediaElement is recreated with the modified resource.
	 // The new resource has a modified start time, so it connects at the point it was playing last.
	 // We also set the forceNoSubclip metadata to true so that the entire timeline is retained for seeking around.
	 //****************************************************************************************
	 */
	public class HDN2LiveArchiveTransitionSample extends BaseSample
	{
		// The HDS URL of the live DVR stream.
		private static const MEDIA_RESOURCE:String = "<YOUR TEST LIVE STREAM HERE>";
		private static const AKAMAI_PLUGIN_INFO:String = "com.akamai.osmf.AkamaiAdvancedStreamingPluginInfo";
		private static const forceRefAkamai:AkamaiAdvancedStreamingPluginInfo = null;
		private var _media:MediaElement = null;
		
		override protected function get pluginURL():String
		{
			return AKAMAI_PLUGIN_INFO;
		}
		
		override protected function createView():BaseVideoView
		{
			return new SampleVideoView();
		}
		
		override protected function onAddedToStage(event:Event):void
		{
			super.onAddedToStage(event);
			
			view.mediaPlayerSprite.mediaPlayer.addEventListener(TimeEvent.COMPLETE, onComplete);			
		}
		
		override protected function createControlBarPresenter():BaseControlBarPresenter
		{
			return new SampleControlBarPresenter(view, BaseVideoView(view).mediaPlayerSprite.mediaPlayer,
				BaseVideoView(view).mediaPlayerSprite.mediaFactory, MEDIA_RESOURCE);
		}
		
		/**
		 * Use the onComplete() event to start the archive retry sequence.
		 * Refer to documentation of the LiveArchiveTransitionEvent class for more details.
		 */
		private function onComplete(event:TimeEvent):void
		{
			view.mediaPlayerSprite.mediaPlayer.removeEventListener(TimeEvent.COMPLETE, onComplete);
			var transitionTime:Number = event.time;
						
			// Start the transition request sequence.
			var _transitionHandler:AkamaiLiveArchiveTransitionHandler = new AkamaiLiveArchiveTransitionHandler();
			_transitionHandler.addEventListener(AkamaiLiveArchiveTransitionEvent.LIVE_ARCHIVE_TRANSITION_REQUESTED, onLiveArchiveTransitionRequested);
			_transitionHandler.addEventListener(AkamaiLiveArchiveTransitionEvent.LIVE_ARCHIVE_TRANSITION_COMPLETE, onLiveArchiveTransitionComplete);
			_transitionHandler.startTransitionRequestSequence(MEDIA_RESOURCE);
			
			function onLiveArchiveTransitionRequested(event:AkamaiLiveArchiveTransitionEvent):void
			{
				_transitionHandler.removeEventListener(AkamaiLiveArchiveTransitionEvent.LIVE_ARCHIVE_TRANSITION_REQUESTED, onLiveArchiveTransitionRequested);
				/**
				 * Player developer could add a custom UI to notify that the request for live archive transition
				 * has been initiated.
				 */
			}
			
			function onLiveArchiveTransitionComplete(event:AkamaiLiveArchiveTransitionEvent):void
			{
				_transitionHandler.removeEventListener(AkamaiLiveArchiveTransitionEvent.LIVE_ARCHIVE_TRANSITION_COMPLETE, onLiveArchiveTransitionComplete);
				//Create a new resource with the modified start time.
				var resource:StreamingURLResource = new StreamingURLResource(MEDIA_RESOURCE, StreamType.LIVE_OR_RECORDED, transitionTime);
				addMetadata(resource);
				
				// Create the media element with the modified resource.
				(view as SampleVideoView).mediaPlayerSprite.mediaPlayer.media = (view as SampleVideoView).mediaPlayerSprite.mediaFactory.createMediaElement(resource);
				
				if ((view as SampleVideoView).mediaPlayerSprite.mediaPlayer.media != null)
				{
					_media = (view as SampleVideoView).mediaPlayerSprite.mediaPlayer.media;
					
					// Add listeners to TRAIT_ADD. When the playTrait gets added, the play() call can be issued on it.
					_media.addEventListener(MediaElementEvent.TRAIT_ADD, onTraitAdd);					
				}
				
				function addMetadata(resource:MediaResourceBase):void
				{
					var metadata:Metadata = resource.getMetadataValue(AkamaiStrings.AKAMAI_ADVANCED_STREAMING_PLUGIN_METADATA_NAMESPACE) as Metadata;
					
					if (metadata == null)
					{
						metadata = new Metadata();		
					}
					
					// Set forceNoSubclip to true, so the archive stream starts from the point of previous disconnect.
					metadata.addValue(AkamaiStrings.AKAMAI_METADATA_KEY_HDN2_FORCE_NO_SUBCLIP, true);
					resource.addMetadataValue(AkamaiStrings.AKAMAI_ADVANCED_STREAMING_PLUGIN_METADATA_NAMESPACE, metadata);
				}
				
				function onTraitAdd(event:MediaElementEvent):void
				{
					if (event.traitType == MediaTraitType.PLAY)
					{
						// Issue play. The stream should resume from the same point where it was prior to EOS.
						_media.removeEventListener(MediaElementEvent.TRAIT_ADD, onTraitAdd);
						(_media.getTrait(MediaTraitType.PLAY) as PlayTrait).play();
					}
				}
			}		
		}
	}
}